@@ -24,6 +24,7 @@
 #include <string.h>
 #include <stdlib.h>
 
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 #include <panel-applet.h>
@@ -338,7 +339,7 @@ display_text (gchar *title, gchar *text, gboolean editable)
                               G_CALLBACK (gtk_widget_destroy), dialog);
 
     scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-    gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), scrolled_window);
+    gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), scrolled_window);
 
     text_view = gtk_text_view_new ();
     gtk_text_view_set_editable (GTK_TEXT_VIEW (text_view), editable);
@@ -665,6 +666,18 @@ dvi_cb (GtkMenuItem *menuitem, SeahorseApplet *sapplet)
             (GtkClipboardTextReceivedFunc)dvi_received, sapplet);
 }
 
+static void
+close_props (GtkButton *button, SeahorseWidget *swidget)
+{
+    seahorse_widget_destroy (swidget);
+}
+
+static void
+win_destroyed (GtkWidget *widget, GdkEvent *event, SeahorseWidget *swidget)
+{
+    seahorse_widget_destroy (swidget);
+}
+
 void
 properties_cb (BonoboUIComponent *uic, SeahorseApplet *sapplet, const char *verbname)
 {
@@ -674,7 +687,7 @@ properties_cb (BonoboUIComponent *uic, SeahorseApplet *sapplet, const char *verb
     
     swidget = seahorse_widget_new ("applet-preferences", NULL);
     
-    widget = glade_xml_get_widget (swidget->xml, swidget->name);
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, swidget->name));
 
     pixbuf = gtk_widget_render_icon (widget, 
                                      ICON_CLIPBOARD_DEFAULT, 
@@ -689,22 +702,28 @@ properties_cb (BonoboUIComponent *uic, SeahorseApplet *sapplet, const char *verb
     if (!swidget)
         return;
     
-    widget = glade_xml_get_widget (swidget->xml, "show-clipboard-state");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "show-clipboard-state"));
     if (widget && GTK_IS_CHECK_BUTTON (widget))
         seahorse_check_button_gconf_attach (GTK_CHECK_BUTTON (widget), SHOW_CLIPBOARD_STATE_KEY);
     
-    widget = glade_xml_get_widget (swidget->xml, "display-encrypted-clipboard");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "display-encrypted-clipboard"));
     if (widget && GTK_IS_CHECK_BUTTON (widget))
         seahorse_check_button_gconf_attach (GTK_CHECK_BUTTON (widget), DISPLAY_CLIPBOARD_ENC_KEY);
     
-    widget = glade_xml_get_widget (swidget->xml, "display-decrypted-clipboard");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "display-decrypted-clipboard"));
     if (widget && GTK_IS_CHECK_BUTTON (widget))
         seahorse_check_button_gconf_attach (GTK_CHECK_BUTTON (widget), DISPLAY_CLIPBOARD_DEC_KEY);
         
-    widget = glade_xml_get_widget (swidget->xml, "display-verified-clipboard");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "display-verified-clipboard"));
     if (widget && GTK_IS_CHECK_BUTTON (widget))
-        seahorse_check_button_gconf_attach (GTK_CHECK_BUTTON (widget), DISPLAY_CLIPBOARD_VER_KEY);    
-    
+        seahorse_check_button_gconf_attach (GTK_CHECK_BUTTON (widget), DISPLAY_CLIPBOARD_VER_KEY);
+
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "close"));
+    g_signal_connect (widget, "clicked", G_CALLBACK (close_props), swidget);
+
+    widget = seahorse_widget_get_toplevel (swidget);
+    g_signal_connect (widget, "delete-event", G_CALLBACK (win_destroyed), swidget);
+
     seahorse_widget_show (swidget);
 }
 
@@ -732,16 +751,18 @@ seahorse_popup_position_menu (GtkMenu *menu, int *x, int *y, gboolean *push_in,
 {
     GtkWidget *widget;
     GtkRequisition requisition;
+    GtkAllocation allocation;
     gint menu_xpos;
     gint menu_ypos;
 
     widget = GTK_WIDGET (gdata);
 
     gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
-    gdk_window_get_origin (widget->window, &menu_xpos, &menu_ypos);
+    gdk_window_get_origin (gtk_widget_get_window (widget), &menu_xpos, &menu_ypos);
 
-    menu_xpos += widget->allocation.x;
-    menu_ypos += widget->allocation.y;
+    gtk_widget_get_allocation (widget, &allocation);
+    menu_xpos += allocation.x;
+    menu_ypos += allocation.y;
 
     switch (panel_applet_get_orient (PANEL_APPLET (widget))) {
     case PANEL_APPLET_ORIENT_DOWN:
@@ -749,14 +770,14 @@ seahorse_popup_position_menu (GtkMenu *menu, int *x, int *y, gboolean *push_in,
         if (menu_ypos > gdk_screen_get_height (gtk_widget_get_screen (widget)) / 2)
             menu_ypos -= requisition.height;
         else
-            menu_ypos += widget->allocation.height;
+            menu_ypos += allocation.height;
         break;
     case PANEL_APPLET_ORIENT_RIGHT:
     case PANEL_APPLET_ORIENT_LEFT:
         if (menu_xpos > gdk_screen_get_width (gtk_widget_get_screen (widget)) / 2)
             menu_xpos -= requisition.width;
         else
-            menu_xpos += widget->allocation.width;
+            menu_xpos += allocation.width;
         break;
     default:
         g_assert_not_reached ();
@@ -907,7 +928,7 @@ seahorse_applet_change_background (PanelApplet *applet, PanelAppletBackgroundTyp
         gtk_widget_modify_bg (GTK_WIDGET (applet), GTK_STATE_NORMAL, colour);
         break;
     case PANEL_PIXMAP_BACKGROUND:
-        style = gtk_style_copy (GTK_WIDGET (applet)->style);
+        style = gtk_style_copy (gtk_widget_get_style (GTK_WIDGET (applet)));
 
         if (style->bg_pixmap[GTK_STATE_NORMAL])
             g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
